==> haskell-monad-par-0.3.4.8-12-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-monad-par.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-par
version: 0.3.4.8
id: monad-par-0.3.4.8-5YPwVW2MbBeEmXVkRax7wK
key: monad-par-0.3.4.8-5YPwVW2MbBeEmXVkRax7wK
license: BSD3
copyright: (c) Simon Marlow 2011
maintainer: Simon Marlow <marlowsd@gmail.com>, Ryan Newton <rrnewton@gmail.com>
stability: Experimental
homepage: https://github.com/simonmar/monad-par
synopsis: A library for parallel programming based on a monad
description:
    The '\''Par'\'' monad offers a simple API for parallel programming.  The
    library works for parallelising both pure and @IO@ computations,
    although only the pure version is deterministic.  The default
    implementation provides a work-stealing scheduler and supports
    forking tasks that are much lighter weight than IO-threads.
    .
    For complete documentation see "Control.Monad.Par".
    .
    Some examples of use can be found in the @examples/@ directory of
    the source package.
    .
    Other related packages:
    .
    * @abstract-par@ provides the type classes that abstract over different
    implementations of the @Par@ monad.
    .
    * @monad-par-extras@ provides extra combinators and monad transformers layered on top of
    the @Par@ monad.
    .
    Changes in 0.3.4 relative to 0.3:
    .
    * Fix bugs that cause "thread blocked indefinitely on MVar" crashes.
    .
    * Added "Control.Monad.Par.IO"
category: Control,Parallelism,Monads
author: Simon Marlow, Ryan Newton
exposed: True
indefinite: False
exposed-modules:
    Control.Monad.Par Control.Monad.Par.IO
    Control.Monad.Par.Scheds.Direct Control.Monad.Par.Scheds.Sparks
    Control.Monad.Par.Scheds.Trace
    Control.Monad.Par.Scheds.TraceInternal
hidden-modules: Control.Monad.Par.Scheds.DirectInternal
abi: fa75bf68ebec5f22dfe262c2538ac5ed
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/monad-par-0.3.4.8
library-dirs: /usr/lib/ghc-8.2.2/site-local/monad-par-0.3.4.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/monad-par-0.3.4.8
hs-libraries: HSmonad-par-0.3.4.8-5YPwVW2MbBeEmXVkRax7wK
depends:
    base-4.10.1.0 abstract-par-0.3.3-34FTxNhMsvaFqPXytGYk6c
    abstract-deque-0.3-2koRGk0qTMQE4aX1mMpi3R
    monad-par-extras-0.3.3-LdK4mOz2PwAKZ9v6fa6Ycz deepseq-1.4.3.0
    array-0.5.2.0 mwc-random-0.13.6.0-KJiIvjcL2lWLnFThQq321j
    containers-0.5.10.2 parallel-3.2.1.1-6PIhrl6oqe7Af1Z2sa6T1
    mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             abstract-par-0.3.3-34FTxNhMsvaFqPXytGYk6c=3244c57c239e3b2973c639ecee30ef29
             abstract-deque-0.3-2koRGk0qTMQE4aX1mMpi3R=bb7f56e761a133974edc0be289658ed9
             monad-par-extras-0.3.3-LdK4mOz2PwAKZ9v6fa6Ycz=b9b42ce2dfc79f0cbf95655a81f81907
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             mwc-random-0.13.6.0-KJiIvjcL2lWLnFThQq321j=d987008159c99ec9f543473509d028a5
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             parallel-3.2.1.1-6PIhrl6oqe7Af1Z2sa6T1=f329a0732f0d1ccfb717a7145bfd3a72
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
haddock-interfaces: /usr/share/doc/haskell-monad-par/html/monad-par.haddock
haddock-html: /usr/share/doc/haskell-monad-par/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-par-0.3.4.8-13-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-monad-par.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-par
version: 0.3.4.8
id: monad-par-0.3.4.8-DWdwEc7MpdP48dIqPl3JX2
key: monad-par-0.3.4.8-DWdwEc7MpdP48dIqPl3JX2
license: BSD3
copyright: (c) Simon Marlow 2011
maintainer: Simon Marlow <marlowsd@gmail.com>, Ryan Newton <rrnewton@gmail.com>
stability: Experimental
homepage: https://github.com/simonmar/monad-par
synopsis: A library for parallel programming based on a monad
description:
    The '\''Par'\'' monad offers a simple API for parallel programming.  The
    library works for parallelising both pure and @IO@ computations,
    although only the pure version is deterministic.  The default
    implementation provides a work-stealing scheduler and supports
    forking tasks that are much lighter weight than IO-threads.
    .
    For complete documentation see "Control.Monad.Par".
    .
    Some examples of use can be found in the @examples/@ directory of
    the source package.
    .
    Other related packages:
    .
    * @abstract-par@ provides the type classes that abstract over different
    implementations of the @Par@ monad.
    .
    * @monad-par-extras@ provides extra combinators and monad transformers layered on top of
    the @Par@ monad.
    .
    Changes in 0.3.4 relative to 0.3:
    .
    * Fix bugs that cause "thread blocked indefinitely on MVar" crashes.
    .
    * Added "Control.Monad.Par.IO"
category: Control,Parallelism,Monads
author: Simon Marlow, Ryan Newton
exposed: True
indefinite: False
exposed-modules:
    Control.Monad.Par Control.Monad.Par.IO
    Control.Monad.Par.Scheds.Direct Control.Monad.Par.Scheds.Sparks
    Control.Monad.Par.Scheds.Trace
    Control.Monad.Par.Scheds.TraceInternal
hidden-modules: Control.Monad.Par.Scheds.DirectInternal
abi: 25cf2c08d7a6b64332e32f1b0adf0c90
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/monad-par-0.3.4.8
library-dirs: /usr/lib/ghc-8.2.2/site-local/monad-par-0.3.4.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/monad-par-0.3.4.8
hs-libraries: HSmonad-par-0.3.4.8-DWdwEc7MpdP48dIqPl3JX2
depends:
    base-4.10.1.0 abstract-par-0.3.3-34FTxNhMsvaFqPXytGYk6c
    abstract-deque-0.3-2koRGk0qTMQE4aX1mMpi3R
    monad-par-extras-0.3.3-IStR7Q2U2bk6k7KVIXlx8h deepseq-1.4.3.0
    array-0.5.2.0 mwc-random-0.13.6.0-KJiIvjcL2lWLnFThQq321j
    containers-0.5.10.2 parallel-3.2.1.1-6PIhrl6oqe7Af1Z2sa6T1
    mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             abstract-par-0.3.3-34FTxNhMsvaFqPXytGYk6c=3244c57c239e3b2973c639ecee30ef29
             abstract-deque-0.3-2koRGk0qTMQE4aX1mMpi3R=bb7f56e761a133974edc0be289658ed9
             monad-par-extras-0.3.3-IStR7Q2U2bk6k7KVIXlx8h=20ae3e2c547344077d8ce7b72400c8e2
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
             array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             mwc-random-0.13.6.0-KJiIvjcL2lWLnFThQq321j=d987008159c99ec9f543473509d028a5
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             parallel-3.2.1.1-6PIhrl6oqe7Af1Z2sa6T1=f329a0732f0d1ccfb717a7145bfd3a72
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
haddock-interfaces: /usr/share/doc/haskell-monad-par/html/monad-par.haddock
haddock-html: /usr/share/doc/haskell-monad-par/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
